@@ -35,7 +35,7 @@ impl<'a, I: Tokens> Parser<I> {
     pub(super) fn parse_assignment_expr(&mut self) -> PResult<Box<Expr>> {
         trace_cur!(self, parse_assignment_expr);
 
-        if self.input.syntax().typescript() {
+        if self.input.syntax().typescript() && self.input.syntax().jsx() {
             // Note: When the JSX plugin is on, type assertions (`<T> x`) aren't valid
             // syntax.
 
@@ -751,7 +751,7 @@ impl<'a, I: Tokens> Parser<I> {
                     Ok(&Token::BinOp(..)) => {
                         // ) is required
                         self.emit_err(self.input.cur_span(), SyntaxError::TS1005);
-                        let errored_expr =
+                        let errorred_expr =
                             self.parse_bin_op_recursively(Box::new(arrow_expr.into()), 0)?;
 
                         if !is!(self, ';') {
@@ -759,7 +759,7 @@ impl<'a, I: Tokens> Parser<I> {
                             self.emit_err(self.input.cur_span(), SyntaxError::TS1005);
                         }
 
-                        return Ok(errored_expr);
+                        return Ok(errorred_expr);
                     }
                     _ => {}
                 },
